/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.tool.url');

/**
 * Do not call this constructor. Decalred to and used by the {@see org.ametys.uitool.ToolsManager}
 * @constructor
 * @class The factory to creates page tools.
 * @param {String} id The unique id of the factory
 * @param {Map} config Options are : 'url' : the url to use to display page, with a 'path' parameter to place the page path; 'default-location' : where to place the tool; 'description' : the tooltip to display with following parameters 'siteUrl', 'siteTitle', 'lang', 'path'.
 * @param {String} pluginName The name of the plugin where the factory was declared
 */
org.ametys.cms.tool.iframe.IframeToolFactory = function(id, config, pluginName) 
{
	org.ametys.cms.tool.iframe.IframeToolFactory.superclass.constructor.call(this, id, config, pluginName);
};

org.ametys.cms.tool.iframe.IframeToolFactory._toolIdPrefix = "iframe-";

Ext.extend(org.ametys.cms.tool.iframe.IframeToolFactory, org.ametys.uitool.tool.ToolFactory, {});

org.ametys.cms.tool.iframe.IframeToolFactory.prototype.openTool = function (params)
{
	if (org.ametys.uitool.ToolsManager.getInstance().getTool(org.ametys.cms.tool.iframe.IframeToolFactory._toolIdPrefix + params.url) == null)
	{
		// Tool does not exists => Tool creation
		this._config['title'] = "...";
		var tool = new org.ametys.cms.tool.iframe.IframeTool (org.ametys.cms.tool.iframe.IframeToolFactory._toolIdPrefix + params.url, this.getPluginName());
		
		tool.setConfiguration(this._config);
		tool.setFactory (this);
		
		org.ametys.uitool.ToolsManager.getInstance().addUITool (tool, this._config['default-location']);
	}
	else
	{
		// Tool does already exists => Tool activation
		tool = org.ametys.uitool.ToolsManager.getInstance().getTool(org.ametys.cms.tool.iframe.IframeToolFactory._toolIdPrefix + params.url);
	}

	tool.setParams(params);
	tool.activate();

	return tool;
}

org.ametys.cms.tool.iframe.IframeToolFactory.prototype.closeTool = function (tool)
{
	org.ametys.uitool.ToolsManager.getInstance().removeUITool (tool);
}
